@@ -8,12 +8,13 @@ from .LDA import run_lda
 from .summarizer import lda_filter_articles_anomalies, get_summaries_by_topic, run_summary
 
 class Huginn:
-    def __init__(self, keyword):
+    def __init__(self, keyword, mid=True):
         """Create a Huginn object
         :argument keyword: person or entity you would like information about
         """
         self.name = keyword
-        self.__mid = get_mid(self.name) #private attribute
+        if mid: self.__mid = get_mid(self.name) #private attribute
+        else: self.__mid = None
         self.interest = get_interest(self.name, self.__mid)
 
     def get_anomalies(self, method="ewm", **kwargs):
@@ -40,13 +41,13 @@ class Huginn:
         """Method to check if get_anomalies has been called, used primarily as a check in later functions"""
         if not hasattr(self, 'anomalies'):
             raise AttributeError('Huginn has not gotten anomalies yet. Use \'get_anomalies\'.')
-            
+
     #private method
     def __check_got_articles(self):
         """Method to check if get_articles_info has been called, used primarily as a check in later functions"""
         if not hasattr(self, 'articles'):
             raise AttributeError('Huginn has not gotten articles yet. Use \'get_articles_info\'.')
-            
+
     #private method
     def __check_got_summaries(self):
         """Method to check if get_articles_info_and_summary_after_LDA has been called, used primarily as a check in later functions"""
@@ -69,7 +70,7 @@ class Huginn:
             plot_data_with_anomalies(self.interest, self.anomalies)
         else:
             return plot_data_with_anomalies_plotly(self.interest, self.anomalies)
-    
+
     def get_articles_info(self, num_links='all'):
         """Get all information about articles (images, urls, content, titles) for each anomaly
         :argument num_links: number of links to keep for each anomaly ('all' by default). The maximum number of articles is 10 due to API quota limit.
@@ -103,32 +104,32 @@ class Huginn:
         self.__check_got_anomalies()
         self.__check_got_articles()
         self.__get_topics_with_lda(n_components = n_components)
-        
+
         lda_filter_articles = lda_filter_articles_anomalies(self.__lda_output, self.articles)
         self.summary_by_anomalies_by_topics = get_summaries_by_topic(lda_filter_articles, min_length, max_length)
-        
+
         return self.summary_by_anomalies_by_topics
-    
+
     def get_global_summary(self, min_length = 50, max_length = 150):
         """Get a global summary (summarize all articles as one)
         No LDA, no matter what the anomaly date is.
         """
         self.__check_got_anomalies()
         self.__check_got_articles()
-        
+
         sentence = ' '.join([text for texts in list(self.articles.values()) for text in texts]) #concatenate all articles
-        
+
         self.global_summary = run_summary(sentence, min_length, max_length)
         return self.global_summary
-    
+
     def get_summary_of_summaries(self, min_length = 50, max_length = 150):
         """Get summary of summaries to compare with get_global_summary
         :argument max_length: max length of the summary
         :returns str (summary)
         """
         self.__check_got_summaries() #check if summaries are available
-        
+
         tmp = [list(dic.values()) for dic in list(self.summary_by_anomalies_by_topics.values())]
         sentence = ' '.join([text for texts in tmp for text in texts]) #concatenate all summaries
         self.summary_of_summaries = run_summary(sentence, min_length, max_length)
-        return self.summary_of_summaries
\ No newline at end of file
+        return self.summary_of_summaries
